==> opensearch-dashboards-2.12.0-1-x86_64.pkg.tar.zst: usr/share/opensearch-dashboards/src/plugins/usage_collection/common/constants.js <==
"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.OPENSEARCH_DASHBOARDS_STATS_TYPE = exports.DEFAULT_MAXIMUM_WAIT_TIME_FOR_ALL_COLLECTORS_IN_S = void 0;
/*
 * SPDX-License-Identifier: Apache-2.0
 *
 * The OpenSearch Contributors require contributions made to
 * this file be licensed under the Apache-2.0 license or a
 * compatible open source license.
 *
 * Any modifications Copyright OpenSearch Contributors. See
 * GitHub history for details.
 */

/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

const OPENSEARCH_DASHBOARDS_STATS_TYPE = exports.OPENSEARCH_DASHBOARDS_STATS_TYPE = 'opensearch_dashboards_stats';
const DEFAULT_MAXIMUM_WAIT_TIME_FOR_ALL_COLLECTORS_IN_S = exports.DEFAULT_MAXIMUM_WAIT_TIME_FOR_ALL_COLLECTORS_IN_S = 60;

==> opensearch-dashboards-3.3.0-1-x86_64.pkg.tar.zst: usr/share/opensearch-dashboards/src/plugins/usage_collection/common/constants.js <==
"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.OPENSEARCH_DASHBOARDS_STATS_TYPE = exports.DEFAULT_MAXIMUM_WAIT_TIME_FOR_ALL_COLLECTORS_IN_S = exports.DEFAULT_BATCHING_INTERVAL_FOR_UI_METRIC_IN_S = void 0;
/*
 * SPDX-License-Identifier: Apache-2.0
 *
 * The OpenSearch Contributors require contributions made to
 * this file be licensed under the Apache-2.0 license or a
 * compatible open source license.
 *
 * Any modifications Copyright OpenSearch Contributors. See
 * GitHub history for details.
 */

/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

const OPENSEARCH_DASHBOARDS_STATS_TYPE = exports.OPENSEARCH_DASHBOARDS_STATS_TYPE = 'opensearch_dashboards_stats';
const DEFAULT_MAXIMUM_WAIT_TIME_FOR_ALL_COLLECTORS_IN_S = exports.DEFAULT_MAXIMUM_WAIT_TIME_FOR_ALL_COLLECTORS_IN_S = 60;
const DEFAULT_BATCHING_INTERVAL_FOR_UI_METRIC_IN_S = exports.DEFAULT_BATCHING_INTERVAL_FOR_UI_METRIC_IN_S = 60;
